It is strongly recommended to add a Network Security Configuration settings enabling encrypted traffic only.

Use of a custom Certificate Authority with certificate pinning increases the security of you application and is
recommended for security sensitive application.